<?php
/**
 * WEN Associate Theme Customizer
 *
 * @package WEN Associate
 */

/**
 * Add partial refresh support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_associate_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

    // Abort if selective refresh is not available.
    if ( ! isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->get_setting( 'blogname' )->transport        = 'refresh';
		$wp_customize->get_setting( 'blogdescription' )->transport = 'refresh';
        return;
    }

    // Load customizer partials callback.
    require get_template_directory() . '/inc/customizer/partials.php';

    // Partial blogname.
    $wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector'            => '.site-title a',
		'container_inclusive' => false,
		'render_callback'     => 'wen_associate_customize_partial_blogname',
    ) );

    // Partial blogdescription.
    $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector'            => '.site-description',
		'container_inclusive' => false,
		'render_callback'     => 'wen_associate_customize_partial_blogdescription',
    ) );

}

add_action( 'customize_register', 'wen_associate_customize_register' );

/**
 * Add Upgrade To Pro button.
 *
 * @since 1.0.0
 */
function wen_associate_custom_customizer_button() {

	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_register_script( 'wen-associate-customizer-button', get_template_directory_uri() . '/assets/js/customizer-button' . $min . '.js', array( 'customize-controls' ), '1.0.0', true );
	$data = array(
		'updrade_button_text' => __( 'Buy WEN Associate Pro', 'wen-associate' ),
		'updrade_button_link' => esc_url( 'http://themepalace.com/downloads/wen-associate-pro/' ),
	);
	wp_localize_script( 'wen-associate-customizer-button', 'WEN_Associate_Customizer_Object', $data );
	wp_enqueue_script( 'wen-associate-customizer-button' );

}

add_action( 'customize_controls_enqueue_scripts', 'wen_associate_custom_customizer_button' );

/**
 * Load styles for Customizer.
 */
function wen_associate_load_customizer_styles() {

	global $pagenow;

	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	if ( 'customize.php' === $pagenow ) {
		wp_enqueue_style( 'wen-associate-customizer-style', get_template_directory_uri() . '/assets/css/customizer' . $min . '.css', false, '1.8.0' );
	}

}

add_action( 'admin_enqueue_scripts', 'wen_associate_load_customizer_styles' );
